@@ -18,6 +18,8 @@ from mock import Mock
 from nose.tools import eq_, ok_
 from metlog.senders.dev import DebugCaptureSender
 
+import socket
+import os
 import threading
 import time
 
@@ -29,15 +31,18 @@ except:
 
 class TestMetlogClient(object):
     logger = 'tests'
+    timer_name = 'test'
 
     def setUp(self):
         self.mock_sender = Mock()
         self.client = MetlogClient(self.mock_sender, self.logger)
         # overwrite the class-wide threadlocal w/ an instance one
         # so values won't persist btn tests
-        self.client.timer._local = threading.local()
+        self.timer_ob = self.client.timer(self.timer_name)
+        self.timer_ob.__dict__['_local'] = threading.local()
 
     def tearDown(self):
+        del self.timer_ob.__dict__['_local']
         del self.mock_sender
 
     def _extract_full_msg(self):
@@ -57,7 +62,8 @@ class TestMetlogClient(object):
         eq_(full_msg['type'], msgtype)
         eq_(full_msg['severity'], self.client.severity)
         eq_(full_msg['logger'], self.logger)
-        eq_(full_msg['fields'], dict())
+        eq_(full_msg['metlog_pid'], os.getpid())
+        eq_(full_msg['metlog_hostname'], socket.gethostname())
         eq_(full_msg['env_version'], self.client.env_version)
 
     def test_metlog_full(self):
@@ -69,28 +75,28 @@ class TestMetlogClient(object):
                                    'boo': 'far'})
         msgtype = 'bawlp'
         self.client.metlog(msgtype, **metlog_args)
-        full_msg = self._extract_full_msg()
+        actual_msg = self._extract_full_msg()
         metlog_args.update({'type': msgtype,
                             'env_version': self.client.env_version,
+                            'metlog_pid': os.getpid(),
+                            'metlog_hostname': socket.gethostname(),
                             'timestamp': metlog_args['timestamp'].isoformat()})
-        eq_(full_msg, metlog_args)
+        eq_(actual_msg, metlog_args)
 
     def test_timer_contextmanager(self):
-        name = 'test'
-        with self.client.timer(name) as result:
+        name = self.timer_name
+        with self.client.timer(name) as timer:
             time.sleep(0.01)
 
-        ok_(result.ms >= 10)
+        ok_(timer.result >= 10)
         full_msg = self._extract_full_msg()
-        eq_(full_msg['payload'], str(result.ms))
+        eq_(full_msg['payload'], str(timer.result))
         eq_(full_msg['type'], 'timer')
         eq_(full_msg['fields']['name'], name)
         eq_(full_msg['fields']['rate'], 1)
 
     def test_timer_decorator(self):
-        name = 'test'
-
-        @self.client.timer(name)
+        @self.client.timer(self.timer_name)
         def timed():
             time.sleep(0.01)
 
@@ -99,11 +105,11 @@ class TestMetlogClient(object):
         full_msg = self._extract_full_msg()
         ok_(int(full_msg['payload']) >= 10)
         eq_(full_msg['type'], 'timer')
-        eq_(full_msg['fields']['name'], name)
+        eq_(full_msg['fields']['name'], self.timer_name)
         eq_(full_msg['fields']['rate'], 1)
 
     def test_timer_with_rate(self):
-        name = 'test'
+        name = self.timer_name
 
         @self.client.timer(name, rate=0.01)
         def timed():
@@ -119,10 +125,13 @@ class TestMetlogClient(object):
     def test_incr(self):
         name = 'incr'
         self.client.incr(name)
+
         full_msg = self._extract_full_msg()
         eq_(full_msg['type'], 'counter')
         eq_(full_msg['logger'], self.logger)
         eq_(full_msg['fields']['name'], name)
+        # You have to have a rate set here
+        eq_(full_msg['fields']['rate'], 1)
         eq_(full_msg['payload'], '1')
 
         self.client.incr(name, 10)
@@ -132,6 +141,7 @@ class TestMetlogClient(object):
 
 class TestDisabledTimer(object):
     logger = 'tests'
+    timer_name = 'test'
 
     def _extract_full_msg(self):
         return json.loads(self.mock_sender.msgs[0])
@@ -141,42 +151,46 @@ class TestDisabledTimer(object):
         self.client = MetlogClient(self.mock_sender, self.logger)
         # overwrite the class-wide threadlocal w/ an instance one
         # so values won't persist btn tests
-        self.client.timer._local = threading.local()
+        self.timer_ob = self.client.timer(self.timer_name)
+        self.timer_ob.__dict__['_local'] = threading.local()
+
+    def tearDown(self):
         self.client.sender.msgs.clear()
+        del self.timer_ob.__dict__['_local']
 
     def test_timer_contextmanager(self):
-        name = 'test'
-        with self.client.timer(name) as result:
+        name = self.timer_name
+        with self.client.timer(name) as timer:
             time.sleep(0.01)
 
-        ok_(result.ms >= 10)
+        ok_(timer.result >= 10)
         full_msg = self._extract_full_msg()
-        eq_(full_msg['payload'], str(result.ms))
+        eq_(full_msg['payload'], str(timer.result))
         eq_(full_msg['type'], 'timer')
         eq_(full_msg['fields']['name'], name)
         eq_(full_msg['fields']['rate'], 1)
 
         # Now disable it
-        self.client._disabled_timers.add('test')
-        with self.client.timer('test') as result:
+        self.client._disabled_timers.add(name)
+        with self.client.timer(name) as timer:
             time.sleep(0.01)
-        ok_(result is None)
+            ok_(timer.result is None)
 
         # Now re-enable it
-        self.client._disabled_timers.remove('test')
+        self.client._disabled_timers.remove(name)
         self.client.sender.msgs.clear()
-        with self.client.timer('test') as result:
+        with self.client.timer(name) as timer:
             time.sleep(0.01)
 
-        ok_(result.ms >= 10)
+        ok_(timer.result >= 10)
         full_msg = self._extract_full_msg()
-        eq_(full_msg['payload'], str(result.ms))
+        eq_(full_msg['payload'], str(timer.result))
         eq_(full_msg['type'], 'timer')
         eq_(full_msg['fields']['name'], name)
         eq_(full_msg['fields']['rate'], 1)
 
     def test_timer_decorator(self):
-        name = 'test'
+        name = self.timer_name
 
         @self.client.timer(name)
         def foo():
@@ -193,7 +207,7 @@ class TestDisabledTimer(object):
         eq_(full_msg['fields']['rate'], 1)
 
         # Now disable it
-        self.client._disabled_timers.add('test')
+        self.client._disabled_timers.add(name)
         self.client.sender.msgs.clear()
 
         @self.client.timer(name)
@@ -204,10 +218,10 @@ class TestDisabledTimer(object):
         eq_(len(self.mock_sender.msgs), 0)
 
         # Now re-enable it
-        self.client._disabled_timers.remove('test')
+        self.client._disabled_timers.remove(name)
         self.client.sender.msgs.clear()
 
-        @self.client.timer('test')
+        @self.client.timer(name)
         def foo3():
             time.sleep(0.01)
         foo3()
@@ -219,7 +233,7 @@ class TestDisabledTimer(object):
         eq_(full_msg['fields']['rate'], 1)
 
     def test_disable_all_timers(self):
-        name = 'test'
+        name = self.timer_name
 
         @self.client.timer(name)
         def foo():
@@ -243,4 +257,4 @@ class TestDisabledTimer(object):
             time.sleep(0.01)
         foo2()
 
-        assert len(self.mock_sender.msgs) == 0
+        eq_(len(self.mock_sender.msgs), 0)
